@@ -4,15 +4,27 @@
 #'
 #' @param doi (character) digital object identifier for an article
 #' @param url (character) the url for the function (should be left to default)
-#' @param key your Crossref OpenURL email address, either enter, or loads 
-#' from \code{.Rprofile}. We use a default, so you don't need to pass this.
-#' @param ... Curl options passed on to \code{\link[httr]{GET}}
+#' @param key your Crossref OpenURL email address, either enter, or loads
+#' from `.Rprofile`. We use a default, so you don't need to pass this.
+#' @param ... Curl options passed on to [crul::HttpClient()]
 #'
 #' @return single numeric value - the citation count, or NA if not found or
 #' no count available
-#' @details See \url{http://labs.crossref.org/openurl/} for more info on this
-#' 		Crossref API service.
-#' @seealso \code{\link{cr_search}}, \code{\link{cr_r}}
+#' @details See <http://labs.crossref.org/openurl/> for more info on this
+#' Crossref API service.
+#'
+#' This number is also known as **cited-by**
+#'
+#' Note that this number may be out of sync/may not match that that the
+#' publisher is showing (if they show it) for the same DOI/article.
+#'
+#' We've contacted Crossref about this, and they have confirmed this.
+#' Unfortunately, we can not do anything about this.
+#'
+#' I would imagine it's best to use this data instead of from the publishers,
+#' and this data you can get programatically :)
+#'
+#' @seealso [cr_search()], [cr_r()]
 #' @author Carl Boettiger \email{cboettig@@gmail.com}
 #' @examples \dontrun{
 #' cr_citation_count(doi="10.1371/journal.pone.0042793")
@@ -23,14 +35,20 @@
 
 cr_citation_count <- function(doi, url = "http://www.crossref.org/openurl/",
 	key = "cboettig@ropensci.org", ...) {
-  
+
   args <- list(id = paste("doi:", doi, sep = ""), pid = as.character(key),
                noredirect = as.logical(TRUE))
-  cite_count <- GET(url, query = args, make_rcrossref_ua(), ...)
-  stop_for_status(cite_count)
-  ans <- xml2::read_xml(ct_utf8(cite_count))
+  cli <- crul::HttpClient$new(
+    url = url,
+    headers = list(
+      `User-Agent` = rcrossref_ua(), `X-USER-AGENT` = rcrossref_ua()
+    )
+  )
+  cite_count <- cli$get(query = args, ...)
+  cite_count$raise_for_status()
+  ans <- xml2::read_xml(cite_count$parse("UTF-8"))
   if (get_attr(ans, "status") == "unresolved") {
-    NA 
+    NA
   } else {
     as.numeric(get_attr(ans, "fl_count"))
   }
